Test Report

# report.html

Report generated on 20-Apr-2021 at 13:47:53 by pytest-html v2.1.1

## Environment

Packages | {"pluggy": "0.13.1", "py": "1.9.0", "pytest": "6.1.1"}
Platform | Linux-5.8.0-36-generic-x86_64-with-glibc2.10
Plugins | {"celery": "4.4.7", "cov": "2.10.0", "dash": "1.19.0", "html": "2.1.1", "hydra-core": "1.1.0.dev5", "metadata": "1.10.0"}
Python | 3.8.3

## Summary

1 tests ran in 0.01 seconds.

(Un)check the boxes to filter the results.

1 passed, 0 skipped, 0 failed, 0 errors, 0 expected failures, 0 unexpected passes

## Results

Result | Test | Duration | Links
--- | --- | --- | ---
No results found. Try to check the filters
Passed | tests/test_sample.py::test_pass | 0.00 |
No log output captured.